Learn R Programming

GFDrmst (version 0.1.1)

summary.GFDrmst: Summarizing RMST-based multiple testing output

Description

summary method for class "GFDrmst".

Usage

# S3 method for GFDrmst
summary(object, digits = 8,...)

Value

No return value, called for side effects.

Arguments

object

An object of class "GFDrmst", usually a result of a call to RMST.test.

digits

An integer indicating the number of decimal places to be used. Default option is 8.

...

Further arguments are ignored.

Details

The function prints the information about the used method, significance level, hypothesis matrices, Wald-type test statistics, adjusted p-values and the overall results of the tests.

See Also

RMST.test

Examples

Run this code
data(colonCS, package = "condSURV")

out <- RMST.test(formula = "Stime ~ rx",
                 event = "event",
                 data = colonCS,
                 hyp_mat = "Tukey",
                 tau = 3000,
                 method = "asymptotic")
summary(out, digits = 3)

Run the code above in your browser using DataLab